<?php
namespace zin;

require_once dirname(__DIR__) . DS . 'formgroup' . DS . 'v1.php';
require_once dirname(__DIR__) . DS . 'formrow' . DS . 'v1.php';
require_once dirname(__DIR__) . DS . 'formbase' . DS . 'v1.php';

/**
 * 通用表单（form）部件类，支持 Ajax 提交
 * The common form widget class
 */
class form extends formBase
{
    /**
     * @var mixed[]
     */
    protected static $defineProps = array(
        'items?: array',    // 使用一个列定义对象数组来定义表单项。
        'horz?: bool=true', // 是否启用水平布局，禅道中所有表单都是网格布局，除非有特殊目的，无需设置此项。
        'labelWidth?: int', // 标签宽度，单位为像素。
        'actionsClass?: string="form-group no-label"', // 操作按钮栏的 CSS 类。
        'submitBtnText?: string' // 提交按钮文本。
    );

    protected function created()
    {
        parent::created();

        if(!isAjaxRequest('modal')) return;

        global $app, $lang;
        $module = $app->getModuleName();
        $method = $app->getMethodName();
        $text   = !empty($lang->$module->$method) ? $lang->$module->$method : zget($lang, $method, '');

        $defaultProps = array();
        $defaultProps['submitBtnText'] = $text;
        $defaultProps['class']         = 'px-3 pb-4';

        $this->setDefaultProps($defaultProps);
    }

    /**
     * @param \zin\item|mixed[] $item
     * @return \zin\wg
     */
    public function onBuildItem($item)
    {
        if(!($item instanceof item))
        {
            if($item instanceof wg) return $item;
            $item = item(set($item));
        }

        if($this->prop('horz')) return new formRow(inherit($item));

        return new formGroup(inherit($item));
    }

    /**
     * @return \zin\wg|null
     */
    protected function buildActions()
    {
        $actions = parent::buildActions();
        if($this->prop('horz') && !empty($actions)) $actions = div(setClass('form-row'), $actions);
        return $actions;
    }

    /**
     * @return mixed[]
     */
    protected function buildProps()
    {
        list($horz, $labelWidth) = $this->prop(array('horz', 'labelWidth'));
        $props = parent::buildProps();
        if($horz)               $props[] = setClass('form-horz');
        if(!empty($labelWidth)) $props[] = setCssVar('form-horz-label-width', $labelWidth);

        return $props;
    }

    /**
     * @return mixed[]
     */
    protected function buildContent()
    {
        list($items, $horz) = $this->prop(array('items', 'horz'));

        $list     = is_array($items) ? array_map(array($this, 'onBuildItem'), $items) : array();
        $children = $this->children();
        if(!empty($children)) $list = array_merge($list, $children);

        if($horz)
        {
            foreach($list as $key => $item)
            {
                if($item instanceof formGroup) $list[$key] = new formRow($item);
            }
        }

        return $list;
    }
}
